.. _phases:

*******************************************
Phase Calculation (`baseband_tasks.phases`)
*******************************************

Introduction
============

The phases module contains classes that help calculate pulsar phases for given
times.  There is support for polycos and for full pulsar timing solutions
(via `pint`).  The purpose of the module is to give these methods a common
interface.

.. note:: Polyco file can be generated by ``tempo``, ``tempo2``, and ``pint``.
          Due to the different treatment of reference phase, the results between
          each other may have a constant offset.

.. _phases_api:

Reference/API
=============

.. automodapi:: baseband_tasks.phases
   :no-inherited-members:
.. automodapi:: baseband_tasks.phases.pint_toas
